@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012-2021 by Christoph Reller. All rights reserved.
+# Copyright (c) 2012-2022 by Christoph Reller. All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -38,7 +38,7 @@
     Author: Christoph Reller <christoph.reller@gmail.com>
 """
 
-__version__ = '0.4.15'
+__version__ = '0.4.16'
 
 import contextlib
 import tempfile
@@ -237,8 +237,11 @@ def cleanup_tikzcode(self, node):
     tikz = tikz.replace('\r\n', '\n')
     tikz = re.sub(r'^\s*%.*$\n', '', tikz, 0, re.MULTILINE)
     tikz = re.sub(r'^\s*$\n', '', tikz, 0, re.MULTILINE)
-    if not tikz.startswith('\\begin{tikz'):
-        tikz = '\\begin{tikzpicture}\n' + tikz + '\n\\end{tikzpicture}'
+    begin_tikz = '\\begin{tikz'
+    if not tikz.startswith(begin_tikz):
+        if begin_tikz not in tikz:
+            tikz = '\\begin{tikzpicture}\n' + tikz + '\n\\end{tikzpicture}'
+
     if 'stringsubst' in node:
         tikz = Template(tikz).safe_substitute(wd=getcwd().replace('\\', '/'))
     return tikz
